Guides
======

We provide three short tutorials on how to use SynDisco. At the end of these
tutorials, you will understand how to set up and execute a synthetic
discussion, annotate it, as well as how to generate and manage up to hundreds
of discussions.

The code for each of these guides can also be found in the
`project's repository <https://github.com/dimits-ts/syndisco/tree/master/docs/guides>`_.

`How to Create a Synthetic Discussion <guides/creating_discussions.ipynb>`_
---------------------------------------------------------------------------

Basic setup including setting up models, actors, and turn-taking strategies.

`How to Annotate your Synthetic Discussions <guides/creating_annotations.ipynb>`_
---------------------------------------------------------------------------------

`How to Use the Experiment API to Manage Large-Scale Studies <guides/creating_experiments.ipynb>`_
--------------------------------------------------------------------------------------------------

Also includes features such as logging and exporting synthetic datasets to CSV
format.
